=======
Credits
=======

This repository is a project of the `Climate Impact Lab <http://www.impactlab.org>`_

Development Lead
----------------

* Justin Simcock <jsimcock@rhg.com>

Contributors
------------

None yet. Why not be the first?
